@@ -35,13 +35,15 @@ class ComponentMeta(type):
 
     def __new__(mcs, name, bases, dct):
         """Create the component class."""
-
         new_class = type.__new__(mcs, name, bases, dct)
         # Don't put the Component base class in the registry
         # Don't put abstract component classes in the registry
-        if name in ('Component', ) or 'abstract' in dct:
-            return new_class
+        if name not in ('Component', ) and 'abstract' not in dct:
+            ComponentMeta.__register_component__(new_class)
+        return new_class
 
+    def __register_component__(new_class):
+        """ Register new_class into component system"""
         ComponentMeta._components.append(new_class)
         if __debug__:
             class_api = set(dir(new_class))
@@ -59,7 +61,6 @@ class ComponentMeta(type):
                 classes = ComponentMeta._registry.setdefault(interface, [])
                 if new_class not in classes:
                     classes.append(new_class)
-        return new_class
 
     def __call__(mcs, *args, **kwargs):
         """
@@ -92,15 +93,18 @@ class ComponentMeta(type):
             compmgr.components[mcs] = self
         return self
 
-    @staticmethod
-    def registered(value):
+    @classmethod
+    def registered(cls, value):
         """Check in class is registered yet"""
 
-        return value in ComponentMeta._components
+        return value in cls._components
 
-    @staticmethod
-    def get_cls(interface):
+    @classmethod
+    def get_cls(cls, interface):
         """Get a copy of valid class registered"""
-
-        cls = ComponentMeta._registry.setdefault(interface, [])
-        return cls[:]
+        if type(interface) not in (str, unicode,):
+            classes = cls._registry.get(interface, [])
+            return classes[:]
+        for key, value in cls._registry.iteritems():
+            if key.__name__ == interface:
+                return value[:]
